==> seedsui-react-2.6.2.tgz: package/es/Dialog/Dialog.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Dialog = (_temp = _class = function (_Component) {
  _inherits(Dialog, _Component);

  function Dialog(props) {
    _classCallCheck(this, Dialog);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidUpdate = function (prevProps) {};

    _this.componentDidMount = function () {};

    _this.onClickMask = function (e) {
      if (_this.props.onClickMask) _this.props.onClickMask(Object.getArgs(e, _this.props.args));
      e.stopPropagation();
    };

    _this.onClickDialog = function (e) {
      e.stopPropagation();
    };

    return _this;
  }
  /* shouldComponentUpdate = (nextProps) => { // 因为是容器,不能使用此方法,不然会影响内部元素的更新
    if (this.props.show === nextProps.show) {
      return false;
    }
    return true;
  } */


  Dialog.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        args = _props.args,
        maskClassName = _props.maskClassName,
        maskStyle = _props.maskStyle,
        isClickMaskHide = _props.isClickMaskHide,
        onClickMask = _props.onClickMask,
        onShowed = _props.onShowed,
        onHid = _props.onHid,
        duration = _props.duration,
        show = _props.show,
        className = _props.className,
        style = _props.style,
        animation = _props.animation,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'args', 'maskClassName', 'maskStyle', 'isClickMaskHide', 'onClickMask', 'onShowed', 'onHid', 'duration', 'show', 'className', 'style', 'animation', 'children']);

    var transformOrigin = 'middle';
    switch (animation) {
      case 'slideLeft':
        transformOrigin = 'right-middle';
        break;
      case 'slideRight':
        transformOrigin = 'left-middle';
        break;
      case 'slideUp':
        transformOrigin = 'bottom-center';
        break;
      case 'slideDown':
        transformOrigin = 'top-center';
        break;
      case 'zoom':
        transformOrigin = 'middle';
        break;
      case 'fade':
        transformOrigin = 'middle';
        break;
      default:
        transformOrigin = 'middle';
    }
    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'mask dialog-mask' + (maskClassName ? ' ' + maskClassName : '') + (show ? ' active' : ''), style: Object.assign(duration !== undefined ? { WebkitTransitionDuration: duration + 'ms' } : {}, maskStyle), onClick: this.onClickMask }, others),
      React.createElement(
        'div',
        { className: 'dialog' + (transformOrigin ? ' ' + transformOrigin : '') + (className ? ' ' + className : '') + (show ? ' active' : ''), style: Object.assign(duration !== undefined ? { WebkitTransitionDuration: duration + 'ms' } : {}, style), 'data-animation': animation, onClick: this.onClickDialog },
        children && children
      )
    ), this.props.portal || document.getElementById('root'));
  };

  return Dialog;
}(Component), _class.defaultProps = {
  args: null,
  isClickMaskHide: false,
  animation: 'fade'
}, _temp);
export { Dialog as default };
Dialog.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  args: PropTypes.any,
  show: PropTypes.bool,

  animation: PropTypes.string, // slideLeft | slideRight | slideUp | slideDown | zoom | fade
  duration: PropTypes.number,
  isClickMaskHide: PropTypes.bool,
  onClickMask: PropTypes.func,
  onShowed: PropTypes.func,
  onHid: PropTypes.func,

  maskClassName: PropTypes.string,
  maskStyle: PropTypes.object,

  className: PropTypes.string,
  style: PropTypes.object,

  children: PropTypes.node
} : {};

==> seedsui-react-2.7.2.tgz: package/es/Dialog/Dialog.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';

var Dialog = (_temp = _class = function (_Component) {
  _inherits(Dialog, _Component);

  function Dialog(props) {
    _classCallCheck(this, Dialog);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.componentDidMount = function () {};

    _this.onClick = function (e) {
      e.stopPropagation();
    };

    return _this;
  }
  /* shouldComponentUpdate = (nextProps) => { // 因为是容器,不能使用此方法,不然会影响内部元素的更新
    if (this.props.show === nextProps.show) {
      return false;
    }
    return true;
  } */

  // 点击dialog主体


  Dialog.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        portal = _props.portal,
        show = _props.show,
        animation = _props.animation,
        _props$maskAttribute = _props.maskAttribute,
        maskAttribute = _props$maskAttribute === undefined ? {} : _props$maskAttribute,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['portal', 'show', 'animation', 'maskAttribute', 'children']);

    var transformOrigin = 'middle';
    switch (animation) {
      case 'slideLeft':
        transformOrigin = 'right-middle';
        break;
      case 'slideRight':
        transformOrigin = 'left-middle';
        break;
      case 'slideUp':
        transformOrigin = 'bottom-center';
        break;
      case 'slideDown':
        transformOrigin = 'top-center';
        break;
      case 'zoom':
        transformOrigin = 'middle';
        break;
      case 'fade':
        transformOrigin = 'middle';
        break;
      default:
        transformOrigin = 'middle';
    }
    return createPortal(React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, maskAttribute, { className: 'mask dialog-mask' + (maskAttribute.className ? ' ' + maskAttribute.className : '') + (show ? ' active' : '') }),
      React.createElement(
        'div',
        _extends({}, others, { className: 'dialog' + (transformOrigin ? ' ' + transformOrigin : '') + (others.className ? ' ' + others.className : '') + (show ? ' active' : ''), onClick: others.onClick ? others.onClick : this.onClick, 'data-animation': animation }),
        children && children
      )
    ), this.props.portal || document.getElementById('root') || document.body);
  };

  return Dialog;
}(Component), _class.defaultProps = {
  animation: 'fade'
}, _temp);
export { Dialog as default };
Dialog.propTypes = process.env.NODE_ENV !== "production" ? {
  portal: PropTypes.object,
  show: PropTypes.bool,

  animation: PropTypes.string, // slideLeft | slideRight | slideUp | slideDown | zoom | fade

  maskAttribute: PropTypes.object,

  children: PropTypes.node
} : {};
